==> gfatpy-0.9.0-py3-none-any.whl: gfatpy/lidar/depolarization/depolarization_calibration_mhc.py <==
import pandas as pd
import datetime as dt


def create_calibration_dataframe_mhc():
    # Dictionary organized by wavelengths
    depoCalib = {"xf": {}}
    # Each wavelength has a depolarization calibration DataFrame
    depoCalib["xf"]["532"] = pd.DataFrame(
        columns=["date", "eta_a", "eta_p", "GR", "GT", "HR", "HT", "K"]
    )

    dict0 = {
        "date": dt.datetime(2015, 6, 7),
        "eta_a": 0.0757,
        "eta_p": 0.1163,
        "GR": 1.0,
        "GT": 1,
        "HR": 1.0,
        "HT": -1.0,
        "K": 1.0,
    }
    dict1 = {
        "date": dt.datetime(2016, 6, 7),
        "eta_a": 0.0757,
        "eta_p": 0.1163,
        "GR": 1.0,
        "GT": 1,
        "HR": 1.0,
        "HT": -1.0,
        "K": 1.0,
    }
    # dict1 = {'date': dt.datetime(2017,9,1), 'eta_a': 0.041, 'eta_p': 0.0717, 'GR':1.31651, 'GT':0.65366, 'HR':1.22341, 'HT':-0.62378, 'K': 1.007}
    # DATE_ROTATIONAL_RAMAN532 = '04/05/2017 00:00:00'
    # dict2 = {'date': dt.datetime(2017,5,5), 'eta_a': 0.041, 'eta_p': 0.0717, 'GR':1.31651, 'GT':0.65366, 'HR':1.22341, 'HT':-0.62378, 'K': 1.007}
    # dict3 = {'date': dt.datetime(2017,5,5), 'eta_a': 0.13, 'eta_p': 0.21, 'GR':1.58726, 'GT':0.41269, 'HR':1.50151, 'HT':-0.33235, 'K': 1.0000}

    # Caso A: Rotator epsilon = 0. alpha = 0.
    dictA = {
        "date": dt.datetime(2017, 5, 5),
        "eta_a": 0.13,
        "eta_p": 0.21,
        "GR": 1.59994,
        "GT": 0.40001,
        "HR": 1.59990,
        "HT": -0.39999,
        "K": 1.000,
    }
    # ===========================================================================================================
    #  GR     , GT     , HR     , HT     ,  K(0.000),  K(0.004), K(0.02) ,  K(0.1) ,  K(0.2) ,  K(0.3) ,  K(0.45)
    #  1.59994, 0.40001, 1.59990,-0.39999,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000
    # ===========================================================================================================

    # Caso B: Rotator epsilon = -5.9. alpha = 0.
    dictB = {
        "date": dt.datetime(2017, 5, 5),
        "eta_a": 0.13,
        "eta_p": 0.21,
        "GR": 1.58726,
        "GT": 0.41269,
        "HR": 1.57877,
        "HT": -0.37886,
        "K": 1.0000,
    }
    # ===========================================================================================================
    # GR     , GT     , HR     , HT     ,  K(0.000),  K(0.004), K(0.02) ,  K(0.1) ,  K(0.2) ,  K(0.3) ,  K(0.45)
    # 1.58726, 0.41269, 1.57877,-0.37886,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000
    # ===========================================================================================================

    # Caso C: Rotator epsilon = 0. alpha = -5.9.
    dictC = {
        "date": dt.datetime(2017, 5, 5),
        "eta_a": 0.13,
        "eta_p": 0.21,
        "GR": 1.59994,
        "GT": 0.40001,
        "HR": 1.56609,
        "HT": -0.39154,
        "K": 1.0000,
    }
    # ===========================================================================================================
    # GR     , GT     , HR     , HT     ,  K(0.000),  K(0.004), K(0.02) ,  K(0.1) ,  K(0.2) ,  K(0.3) ,  K(0.45)
    # 1.59994, 0.40001, 1.56609,-0.39154,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000
    # ===========================================================================================================

    # Caso D: Rotator Alvarez's method alpha+epsilon = -13º --> epsilon = -5.9. alpha = -7.1
    dictD = {
        "date": dt.datetime(2017, 5, 5),
        "eta_a": 0.13,
        "eta_p": 0.21,
        "GR": 1.58726,
        "GT": 0.41269,
        "HR": 1.57066,
        "HT": -0.40741,
        "K": 1.0000,
    }
    # ===========================================================================================================
    # GR     , GT     , HR     , HT     ,  K(0.000),  K(0.004), K(0.02) ,  K(0.1) ,  K(0.2) ,  K(0.3) ,  K(0.45)
    # 1.58726, 0.41269, 1.57066,-0.40741,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000
    # ===========================================================================================================

    # Caso E: Rotator Alvarez's method alpha-epsilon = -13º --> epsilon = -5.9. alpha = -20.9
    dictE = {
        "date": dt.datetime(2017, 5, 5),
        "eta_a": 0.13,
        "eta_p": 0.21,
        "GR": 1.58726,
        "GT": 0.41269,
        "HR": 1.28597,
        "HT": -0.39147,
        "K": 1.0000,
    }
    # ===========================================================================================================
    # GR     , GT     , HR     , HT     ,  K(0.000),  K(0.004), K(0.02) ,  K(0.1) ,  K(0.2) ,  K(0.3) ,  K(0.45)
    # 1.58726, 0.41269, 1.28597,-0.39147,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000
    # ===========================================================================================================

    # Caso F: Rotator Alvarez's method alpha+epsilon = +13º --> epsilon = -5.9. alpha = +20.9
    dictF = {
        "date": dt.datetime(2017, 5, 5),
        "eta_a": 0.13,
        "eta_p": 0.21,
        "GR": 1.58726,
        "GT": 0.41269,
        "HR": 1.06790,
        "HT": -0.17339,
        "K": 1.00004,
    }
    # ===========================================================================================================
    # GR     , GT     , HR     , HT     ,  K(0.000),  K(0.004), K(0.02) ,  K(0.1) ,  K(0.2) ,  K(0.3) ,  K(0.45)
    # 1.58726, 0.41269, 1.06790,-0.17339,  1.00004,  1.00004,  1.00004,  1.00003,  1.00002,  1.00002,  1.00001
    # ===========================================================================================================

    # Caso G: Rotator Alvarez's method alpha+epsilon = +13º --> epsilon = -5.9. alpha = +7.1
    dictG = {
        "date": dt.datetime(2017, 5, 5),
        "eta_a": 0.13,
        "eta_p": 0.21,
        "GR": 1.58726,
        "GT": 0.41269,
        "HR": 1.49040,
        "HT": -0.32715,
        "K": 1.00001,
    }
    # ===========================================================================================================
    # GR     , GT     , HR     , HT     ,  K(0.000),  K(0.004), K(0.02) ,  K(0.1) ,  K(0.2) ,  K(0.3) ,  K(0.45)
    # 1.58726, 0.41269, 1.49040,-0.32715,  1.00001,  1.00001,  1.00001,  1.00001,  1.00001,  1.00001,  1.00000
    # ===========================================================================================================

    # Caso H: Rotator Alvarez's method alpha+epsilon = +13º --> epsilon = +5.9. alpha = +7.1
    dictH = {
        "date": dt.datetime(2017, 5, 5),
        "eta_a": 0.13,
        "eta_p": 0.21,
        "GR": 1.58726,
        "GT": 0.41269,
        "HR": 1.57066,
        "HT": -0.40741,
        "K": 1.0000,
    }
    # ===========================================================================================================
    # GR     , GT     , HR     , HT     ,  K(0.000),  K(0.004), K(0.02) ,  K(0.1) ,  K(0.2) ,  K(0.3) ,  K(0.45)
    # 1.58726, 0.41269, 1.57066,-0.40741,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000
    # ===========================================================================================================

    # Caso I: Rotator Alvarez's method alpha+epsilon = -13º --> epsilon = +5.9. alpha = -20.9
    dictI = {
        "date": dt.datetime(2017, 5, 5),
        "eta_a": 0.13,
        "eta_p": 0.21,
        "GR": 1.58726,
        "GT": 0.41269,
        "HR": 1.06790,
        "HT": -0.17339,
        "K": 1.00004,
    }
    # ===========================================================================================================
    # GR     , GT     , HR     , HT     ,  K(0.000),  K(0.004), K(0.02) ,  K(0.1) ,  K(0.2) ,  K(0.3) ,  K(0.45)
    # 1.58726, 0.41269, 1.06790,-0.17339,  1.00004,  1.00004,  1.00004,  1.00003,  1.00002,  1.00002,  1.00001
    # ===========================================================================================================

    # Caso J: Polarizer epsilon = 15. alpha = 7.1
    dictJ = {
        "date": dt.datetime(2017, 5, 5),
        "eta_a": 0.13,
        "eta_p": 0.21,
        "GR": 3.19952,
        "GT": 0.00010,
        "HR": 3.10176,
        "HT": -0.00006,
        "K": 4.16828,
    }
    # ===========================================================================================================
    # GR     , GT     , HR     , HT     ,  K(0.000),  K(0.004), K(0.02) ,  K(0.1) ,  K(0.2) ,  K(0.3) ,  K(0.45)
    # 2.98522, 0.05367, 2.15126, 0.03558,  4.26295,  4.25698,  4.23541,  4.16358,  4.11450,  4.08424,  4.05465
    # ===========================================================================================================
    # no epsilon
    # ===========================================================================================================
    # GR     , GT     , HR     , HT     ,  K(0.000),  K(0.004), K(0.02) ,  K(0.1) ,  K(0.2) ,  K(0.3) ,  K(0.45)
    # 3.19952, 0.00010, 3.10176,-0.00006,  4.16828,  4.16674,  4.16073,  4.13423,  4.10745,  4.08569,  4.05957
    # ===========================================================================================================

    dict2 = dictG

    dict3 = {
        "date": dt.datetime(2019, 8, 1),
        "eta_a": 0.08,
        "eta_p": 0.21,
        "GR": 1.0,
        "GT": 1,
        "HR": 1.0,
        "HT": -1.0,
        "K": 1.0,
    }

    depoCalib["xf"]["532"].loc[0] = pd.Series(dict0)
    depoCalib["xf"]["532"].loc[1] = pd.Series(dict1)
    depoCalib["xf"]["532"].loc[2] = pd.Series(dict2)
    depoCalib["xf"]["532"].loc[3] = pd.Series(dict3)
    depoCalib["xf"]["532"] = depoCalib["xf"]["532"].set_index("date")
    return depoCalib

==> gfatpy-0.12.2-py3-none-any.whl: gfatpy/lidar/depolarization/depolarization_calibration_mhc.py <==
import pandas as pd
import datetime as dt


def create_calibration_dataframe_mhc():
    # Dictionary organized by wavelengths
    depoCalib = {"xf": {}}
    # Each wavelength has a depolarization calibration DataFrame
    depoCalib["xf"]["532"] = pd.DataFrame(
        columns=["date", "eta_a", "eta_p", "GR", "GT", "HR", "HT", "K"]
    )

    dict0 = {
        "date": dt.datetime(2015, 6, 7),
        "eta_a": 0.0757,
        "eta_p": 0.1163,
        "GR": 1.0,
        "GT": 1,
        "HR": 1.0,
        "HT": -1.0,
        "K": 1.0,
    }
    dict1 = {
        "date": dt.datetime(2016, 6, 7),
        "eta_a": 0.0757,
        "eta_p": 0.1163,
        "GR": 1.0,
        "GT": 1,
        "HR": 1.0,
        "HT": -1.0,
        "K": 1.0,
    }
    # dict1 = {'date': dt.datetime(2017,9,1), 'eta_a': 0.041, 'eta_p': 0.0717, 'GR':1.31651, 'GT':0.65366, 'HR':1.22341, 'HT':-0.62378, 'K': 1.007}
    # DATE_ROTATIONAL_RAMAN532 = '04/05/2017 00:00:00'
    # dict2 = {'date': dt.datetime(2017,5,5), 'eta_a': 0.041, 'eta_p': 0.0717, 'GR':1.31651, 'GT':0.65366, 'HR':1.22341, 'HT':-0.62378, 'K': 1.007}
    # dict3 = {'date': dt.datetime(2017,5,5), 'eta_a': 0.13, 'eta_p': 0.21, 'GR':1.58726, 'GT':0.41269, 'HR':1.50151, 'HT':-0.33235, 'K': 1.0000}

    # Caso A: Rotator epsilon = 0. alpha = 0.
    dictA = {
        "date": dt.datetime(2017, 5, 5),
        "eta_a": 0.13,
        "eta_p": 0.21,
        "GR": 1.59994,
        "GT": 0.40001,
        "HR": 1.59990,
        "HT": -0.39999,
        "K": 1.000,
    }
    # ===========================================================================================================
    #  GR     , GT     , HR     , HT     ,  K(0.000),  K(0.004), K(0.02) ,  K(0.1) ,  K(0.2) ,  K(0.3) ,  K(0.45)
    #  1.59994, 0.40001, 1.59990,-0.39999,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000
    # ===========================================================================================================

    # Caso B: Rotator epsilon = -5.9. alpha = 0.
    dictB = {
        "date": dt.datetime(2017, 5, 5),
        "eta_a": 0.13,
        "eta_p": 0.21,
        "GR": 1.58726,
        "GT": 0.41269,
        "HR": 1.57877,
        "HT": -0.37886,
        "K": 1.0000,
    }
    # ===========================================================================================================
    # GR     , GT     , HR     , HT     ,  K(0.000),  K(0.004), K(0.02) ,  K(0.1) ,  K(0.2) ,  K(0.3) ,  K(0.45)
    # 1.58726, 0.41269, 1.57877,-0.37886,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000
    # ===========================================================================================================

    # Caso C: Rotator epsilon = 0. alpha = -5.9.
    dictC = {
        "date": dt.datetime(2017, 5, 5),
        "eta_a": 0.13,
        "eta_p": 0.21,
        "GR": 1.59994,
        "GT": 0.40001,
        "HR": 1.56609,
        "HT": -0.39154,
        "K": 1.0000,
    }
    # ===========================================================================================================
    # GR     , GT     , HR     , HT     ,  K(0.000),  K(0.004), K(0.02) ,  K(0.1) ,  K(0.2) ,  K(0.3) ,  K(0.45)
    # 1.59994, 0.40001, 1.56609,-0.39154,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000
    # ===========================================================================================================

    # Caso D: Rotator Alvarez's method alpha+epsilon = -13º --> epsilon = -5.9. alpha = -7.1
    dictD = {
        "date": dt.datetime(2017, 5, 5),
        "eta_a": 0.13,
        "eta_p": 0.21,
        "GR": 1.58726,
        "GT": 0.41269,
        "HR": 1.57066,
        "HT": -0.40741,
        "K": 1.0000,
    }
    # ===========================================================================================================
    # GR     , GT     , HR     , HT     ,  K(0.000),  K(0.004), K(0.02) ,  K(0.1) ,  K(0.2) ,  K(0.3) ,  K(0.45)
    # 1.58726, 0.41269, 1.57066,-0.40741,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000
    # ===========================================================================================================

    # Caso E: Rotator Alvarez's method alpha-epsilon = -13º --> epsilon = -5.9. alpha = -20.9
    dictE = {
        "date": dt.datetime(2017, 5, 5),
        "eta_a": 0.13,
        "eta_p": 0.21,
        "GR": 1.58726,
        "GT": 0.41269,
        "HR": 1.28597,
        "HT": -0.39147,
        "K": 1.0000,
    }
    # ===========================================================================================================
    # GR     , GT     , HR     , HT     ,  K(0.000),  K(0.004), K(0.02) ,  K(0.1) ,  K(0.2) ,  K(0.3) ,  K(0.45)
    # 1.58726, 0.41269, 1.28597,-0.39147,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000
    # ===========================================================================================================

    # Caso F: Rotator Alvarez's method alpha+epsilon = +13º --> epsilon = -5.9. alpha = +20.9
    dictF = {
        "date": dt.datetime(2017, 5, 5),
        "eta_a": 0.13,
        "eta_p": 0.21,
        "GR": 1.58726,
        "GT": 0.41269,
        "HR": 1.06790,
        "HT": -0.17339,
        "K": 1.00004,
    }
    # ===========================================================================================================
    # GR     , GT     , HR     , HT     ,  K(0.000),  K(0.004), K(0.02) ,  K(0.1) ,  K(0.2) ,  K(0.3) ,  K(0.45)
    # 1.58726, 0.41269, 1.06790,-0.17339,  1.00004,  1.00004,  1.00004,  1.00003,  1.00002,  1.00002,  1.00001
    # ===========================================================================================================

    # Caso G: Rotator Alvarez's method alpha+epsilon = +13º --> epsilon = -5.9. alpha = +7.1
    dictG = {
        "date": dt.datetime(2017, 5, 5),
        "eta_a": 0.13,
        "eta_p": 0.21,
        "GR": 1.58726,
        "GT": 0.41269,
        "HR": 1.49040,
        "HT": -0.32715,
        "K": 1.00001,
    }
    # ===========================================================================================================
    # GR     , GT     , HR     , HT     ,  K(0.000),  K(0.004), K(0.02) ,  K(0.1) ,  K(0.2) ,  K(0.3) ,  K(0.45)
    # 1.58726, 0.41269, 1.49040,-0.32715,  1.00001,  1.00001,  1.00001,  1.00001,  1.00001,  1.00001,  1.00000
    # ===========================================================================================================

    # Caso H: Rotator Alvarez's method alpha+epsilon = +13º --> epsilon = +5.9. alpha = +7.1
    dictH = {
        "date": dt.datetime(2017, 5, 5),
        "eta_a": 0.13,
        "eta_p": 0.21,
        "GR": 1.58726,
        "GT": 0.41269,
        "HR": 1.57066,
        "HT": -0.40741,
        "K": 1.0000,
    }
    # ===========================================================================================================
    # GR     , GT     , HR     , HT     ,  K(0.000),  K(0.004), K(0.02) ,  K(0.1) ,  K(0.2) ,  K(0.3) ,  K(0.45)
    # 1.58726, 0.41269, 1.57066,-0.40741,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000,  1.00000
    # ===========================================================================================================

    # Caso I: Rotator Alvarez's method alpha+epsilon = -13º --> epsilon = +5.9. alpha = -20.9
    dictI = {
        "date": dt.datetime(2017, 5, 5),
        "eta_a": 0.13,
        "eta_p": 0.21,
        "GR": 1.58726,
        "GT": 0.41269,
        "HR": 1.06790,
        "HT": -0.17339,
        "K": 1.00004,
    }
    # ===========================================================================================================
    # GR     , GT     , HR     , HT     ,  K(0.000),  K(0.004), K(0.02) ,  K(0.1) ,  K(0.2) ,  K(0.3) ,  K(0.45)
    # 1.58726, 0.41269, 1.06790,-0.17339,  1.00004,  1.00004,  1.00004,  1.00003,  1.00002,  1.00002,  1.00001
    # ===========================================================================================================

    # Caso J: Polarizer epsilon = 15. alpha = 7.1
    dictJ = {
        "date": dt.datetime(2017, 5, 5),
        "eta_a": 0.13,
        "eta_p": 0.21,
        "GR": 3.19952,
        "GT": 0.00010,
        "HR": 3.10176,
        "HT": -0.00006,
        "K": 4.16828,
    }
    # ===========================================================================================================
    # GR     , GT     , HR     , HT     ,  K(0.000),  K(0.004), K(0.02) ,  K(0.1) ,  K(0.2) ,  K(0.3) ,  K(0.45)
    # 2.98522, 0.05367, 2.15126, 0.03558,  4.26295,  4.25698,  4.23541,  4.16358,  4.11450,  4.08424,  4.05465
    # ===========================================================================================================
    # no epsilon
    # ===========================================================================================================
    # GR     , GT     , HR     , HT     ,  K(0.000),  K(0.004), K(0.02) ,  K(0.1) ,  K(0.2) ,  K(0.3) ,  K(0.45)
    # 3.19952, 0.00010, 3.10176,-0.00006,  4.16828,  4.16674,  4.16073,  4.13423,  4.10745,  4.08569,  4.05957
    # ===========================================================================================================

    dict2 = dictG

    dict3 = {
        "date": dt.datetime(2019, 8, 1),
        "eta_a": 0.08,
        "eta_p": 0.21,
        "GR": 1.0,
        "GT": 1,
        "HR": 1.0,
        "HT": -1.0,
        "K": 1.0,
    }

    depoCalib["xf"]["532"].iloc[0] = pd.Series(dict0)
    depoCalib["xf"]["532"].iloc[1] = pd.Series(dict1)
    depoCalib["xf"]["532"].iloc[2] = pd.Series(dict2)
    depoCalib["xf"]["532"].iloc[3] = pd.Series(dict3)
    depoCalib["xf"]["532"] = depoCalib["xf"]["532"].set_index("date")
    return depoCalib
